<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Nick</translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation>Nick SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Używaj wbudowanej aplikacji SMS</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Własna aplikacja SMS</translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation>Używaj własnych argumentów SMS</translation>
    </message>
    <message>
        <source>Check this box if your sms application doesn&apos;t understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %n argument is converted to number, %m to message</source>
        <translation>Zaznacz to okienko jeżeli aplikacja SMS nie rozpoznaje argumentów: numer &amp;wiadomość&amp;
Argumenty powinny być oddzielone spacjami. %n jest zamieniane na numer, %m na wiadomość</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>Argumenty SMS</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Bramki</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Wyślij SMS</translation>
    </message>
</context>
<context>
    <name>Sms</name>
    <message>
        <source>Recipient</source>
        <translation>Odbiorca</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Wyślij SMS</translation>
    </message>
    <message>
        <source>Sms application was not specified. Visit the configuration section</source>
        <translation>Wpisz nazwę programu do wysyłania SMS w konfiguracji.</translation>
    </message>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Problem z uruchomieniem programu do wysyłania SMS.</translation>
    </message>
    <message>
        <source>The process exited normally. The SMS should be on its way</source>
        <translation>Proces zakończony prawidłowo. SMS powinien być już w drodze.</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Proces zakończony nieprawidłowo. SMS mógł nie zostać wysłany.</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Kontakt</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Podpis</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>Zapisz SMS w historii</translation>
    </message>
    <message>
        <source>The SMS was sent and should be on its way.
Do you want to send next message?</source>
        <translation>SMS został wysłany i prawdopodobnie jest w drodze.
Chcesz wysłać następną wiadomość?</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Wyślij</translation>
    </message>
</context>
<context>
    <name>SmsConfigurationUiHandler</name>
    <message>
        <source>Send SMS</source>
        <translation>Wyślij SMS</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Przenieś w górę</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Przenieś w dół</translation>
    </message>
    <message>
        <source>Gateways priorites</source>
        <translation>Priorytety bramek</translation>
    </message>
</context>
<context>
    <name>SmsGateway</name>
    <message>
        <source>Network error. Provider gateway page is probably unavailable</source>
        <translation>Wskazana bramka SMS jest prawdopodobnie wyłączona.</translation>
    </message>
</context>
<context>
    <name>SmsImageDialog</name>
    <message>
        <source>Enter text from the picture:</source>
        <translation>Wpisz tekst z obrazka:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>SmsSender</name>
    <message>
        <source>Mobile number is incorrect</source>
        <translation>Numer telefonu jest nieprawidłowy</translation>
    </message>
    <message>
        <source>Mobile number is incorrect or gateway is not available</source>
        <translation>Numer telefonu jest niepoprawny lub bramka jest niedostępna</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty</source>
        <translation>Pole &quot;Podpis&quot; nie może być puste</translation>
    </message>
</context>
</TS>
